package org.zoikks.drools;

import java.util.Collection;

import org.drools.KnowledgeBase;
import org.drools.KnowledgeBaseFactory;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.definition.KnowledgePackage;
import org.drools.event.rule.DebugAgendaEventListener;
import org.drools.event.rule.DebugWorkingMemoryEventListener;
import org.drools.io.ResourceFactory;
import org.drools.runtime.StatefulKnowledgeSession;

/**
 * Sample Process Application
 *
 */
public class ProcessApp 
{
	private StatefulKnowledgeSession ksession;
	
    public static void main( String[] args )
    {
        new ProcessApp();
    }
    
    private ProcessApp() {
    	this.ksession = this.createKnowledgeSession();
    	
    	this.ksession.startProcess("Howdy");
    	this.ksession.fireAllRules();
    }
    
    private StatefulKnowledgeSession createKnowledgeSession() {
        
    	final KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();

    	kbuilder.add(ResourceFactory.newClassPathResource("processes/Hello.bpmn", ProcessApp.class), ResourceType.BPMN2);
		
		if (kbuilder.hasErrors()) {
			System.out.println(kbuilder.getErrors().toString());
			throw new RuntimeException("Unable to compile.");
		}
		
		final Collection<KnowledgePackage> pkgs = kbuilder
				.getKnowledgePackages();
		
		final KnowledgeBase kbase = KnowledgeBaseFactory.newKnowledgeBase();
		kbase.addKnowledgePackages(pkgs);
		
		final StatefulKnowledgeSession ksession = kbase
				.newStatefulKnowledgeSession();
		
//		Uncomment these to turn on Process/Rule logging.
//		ksession.addEventListener(new DebugAgendaEventListener());
//		ksession.addEventListener(new DebugWorkingMemoryEventListener());
		
		return ksession;
    }
}
